@@ -4,7 +4,24 @@ use Encode;
 extends qw(XML::Generator::Moose);
 with qw(XML::Toolkit::Generator::Interface);
 
-after 'xml_decl' => sub { shift->newline };
+has namespace => (
+    isa        => 'Str',
+    is         => 'ro',
+    lazy_build => 1,
+);
+
+sub _build_namespace { 'MyApp' }
+
+with qw(XML::Toolkit::Builder::NamespaceRegistry);
+
+after 'xml_decl' => sub {
+    my $self = shift;
+    for my $prefix ( keys %{ $self->namespace_map } ) {
+        my $uri = $self->namespace_map->{$prefix};
+        $self->start_prefix_mapping( $prefix => $uri, );
+    }
+    $self->newline;
+};
 
 sub get_element_name {
     my ( $self, $meta ) = @_;
@@ -20,8 +37,9 @@ sub get_element_name {
 
 sub is_node {
     my ( $self, $attr ) = @_;
-    return 0 unless $attr->can('description');
-    return 0 unless $attr->description->{node_type};
+    confess "no attribute" unless $attr;
+    return 0               unless $attr->can('description');
+    return 0               unless $attr->description->{node_type};
     return 1;
 }
 
@@ -35,7 +53,7 @@ sub is_child_node {
 sub is_text_node {
     my ( $self, $attr ) = @_;
     return 0 unless $self->is_node($attr);
-    return 1 if $attr->description->{node_type} eq 'characters';
+    return 1 if $attr->description->{node_type} eq 'character';
     return 0;
 }
 
@@ -46,53 +64,47 @@ sub is_attribute_node {
     return 0;
 }
 
-sub get_attrs {
+sub get_attribute_nodes {
     my ( $self, $meta, $obj ) = @_;
     my @attrs = grep { $self->is_attribute_node($_) }
       grep { defined $_->get_value($obj) }
       map  { $meta->get_attribute($_) } $meta->get_attribute_list;
     return map {
-            '{'
-          . $_->description->{Prefix} . '}'
-          . $_->description->{LocalName} =>
+        $_->description->{LocalName} =>
           { %{ $_->description }, Value => $_->get_value($obj) }
     } @attrs;
 }
 
 sub parse_object {
-    my ( $self, $meta, $obj, $parent ) = @_;
-    my %attrs = $self->get_attrs( $meta, $obj );
-    my $name = $self->get_element_name($meta);
-    $self->start_element( $name => \%attrs );
+    my ( $self, $meta, $obj, $descr ) = @_;
+    my %attrs = $self->get_attribute_nodes( $meta, $obj );
+    my $name = $descr->{Name};
+
+    $self->start_element(
+        $name => \%attrs,
+        $descr,
+    );
+
     for my $attr ( $self->_get_sorted_filtered_attributes($meta) ) {
-        next unless $attr->get_value($obj);
-
-        #        next unless $self->is_node($attr);
-        next if $self->is_attribute_node($attr);
-        my $el = $self->get_element_name($attr);
-
-        $self->start_element($el)
-          if $el && !blessed $attr->get_value($obj);
-        for my $child ( $attr->get_value($obj) ) {
-            next unless $child;
-            if ( blessed $child) {
-                $self->parse_object( $child->meta, $child, $attr->name );
-            }
-            else {
-                unless ( ref $child ) {
-                    $self->characters($child);
-                }
+        if ( $self->is_text_node($attr) ) {
+            $self->characters( $attr->get_value($obj) );
+        }
+        elsif ( $self->is_child_node($attr) ) {
+            next unless my $value = $attr->get_value($obj);
+            for my $child ( grep { defined } @$value ) {
+                next unless blessed $child;
+                $self->parse_object( $child->meta, $child, $attr->description );
             }
         }
-        $self->end_element($el)
-          if $el && !blessed $attr->get_value($obj);
+        else { warn "${\$attr->dump} is funky" }
     }
     $self->end_element($name);
 }
 
 augment 'parse' => sub {
     my ( $self, $obj ) = @_;
-    $self->parse_object( $obj->meta, $obj );
+    $self->parse_object( $obj->meta, $obj,
+        { Name => $self->get_element_name( $obj->meta ) } );
 
 };
 
@@ -103,6 +115,7 @@ sub _get_sorted_filtered_attributes {
         return 1  unless exists $b->description->{sort_order};
         return $a->description->{sort_order} <=> $b->description->{sort_order}
       }
+      grep { !$self->is_attribute_node($_) }
       grep { !$_->does('XML::Toolkit::Trait::NoXML') }
       $meta->get_all_attributes;
 }
@@ -143,7 +156,7 @@ See XML::Generator::Moose.
 
 =item is_attribute_node
 
-=item get_attrs
+=item get_attribute_nodes
 
 =item parse_object
 
