@@ -6,8 +6,6 @@ use XML::Toolkit::MetaDescription;
 extends 'MooseX::MetaDescription::Meta::Attribute';
 with 'XML::Toolkit::MetaDescription::Trait';
 
-has '+metadescription_classname' =>
-  ( default => 'XML::Toolkit::MetaDescription' );
 
 no Moose;
 1;
